pub struct AppConfig {
pub app_name: Stringy,
pub version: String,
pub max_ram_usage: usize,
pub max_cpu_usage: usize,
pub environment: String,
pub debug_mode: bool,
pub log_level: LogLevel,
pub git: Option<GitConfig>,
pub database: Option<DatabaseConfig>,
pub aggregator: Option<Aggregator>,
}Expand description
Represents the application’s configuration settings.
Fields
app_name: StringyA name for the application instance.
version: StringVersion of the application.
max_ram_usage: usizeMaximum ram usage in MB
max_cpu_usage: usizeMaximum cpu time usage This would be practically be used to restart a service when it gets to it’s aloted cpu time. A pricing scale be set like this.
environment: StringThe environment the application is running in (e.g., development, staging, production).
debug_mode: boolOptional setting for enabling debug mode.
log_level: LogLevelSettings for what information is logged
git: Option<GitConfig>Configuration related to the Git functionality.
database: Option<DatabaseConfig>Configuration related to the database (optional example).
aggregator: Option<Aggregator>Configuration for Aggregator communication
Implementations
Sourceimpl AppConfig
impl AppConfig
Sourcepub fn new() -> Result<Self, ConfigError>
pub fn new() -> Result<Self, ConfigError>
pub fn get_version(&self) -> Result<SoftwareVersion, ErrorArrayItem>