Structs
- Represents Git authentication information for a repository.
- Represents Git credentials, containing a list of authentication items.
Enums
- Represents various Git actions that can be performed.
- Represents the Git server to interact with.
Constants
Functions
- Generates a unique project ID based on the Git authentication information.
- Generates the project path based on the Git authentication information.