pub struct StatePersistence;Expand description
Provides utility methods for loading and saving AppState from/to disk.
Implementations
Sourceimpl StatePersistence
impl StatePersistence
Sourcepub fn get_state_path(config: &AppConfig) -> PathType
pub fn get_state_path(config: &AppConfig) -> PathType
Derives the default save path for the application state using /opt/artisan/tmp/.<app_name>.state.
Example
let config = AppConfig::dummy();
let path = StatePersistence::get_state_path(&config);
println!("State file path: {:?}", path);Sourcepub async fn save_state(
state: &AppState,
path: &PathType,
) -> Result<(), Box<dyn Error>>
pub async fn save_state( state: &AppState, path: &PathType, ) -> Result<(), Box<dyn Error>>
Saves the provided AppState to the specified path.
The data is serialized to TOML, then encrypted with simple_encrypt.
Errors
- Returns an
Errif serialization, encryption, or writing to the file fails.
Sourcepub async fn load_state(path: &PathType) -> Result<AppState, Box<dyn Error>>
pub async fn load_state(path: &PathType) -> Result<AppState, Box<dyn Error>>
Loads an AppState from the specified path.
Reads the file, then decrypts it with simple_decrypt, and finally deserializes from TOML.
Errors
- Returns an
Errif decryption or TOML deserialization fails, or if the file is unreadable.